=======================================
``psyclone.tests.parse.algorithm_test``
=======================================

.. automodule:: psyclone.tests.parse.algorithm_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.parse.algorithm_test
